@@ -3,7 +3,7 @@
    xsane-device-preferences.c
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2005 Oliver Rauch
+   Copyright (C) 1998-2007 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -47,17 +47,20 @@ static struct
 }
 desc_xsane_device[] =
 {
-    {"xsane-main-window-x-position",             xsane_rc_pref_int, DPOFFSET(shell_posx)},
-    {"xsane-main-window-y-position",             xsane_rc_pref_int, DPOFFSET(shell_posy)},
+    {"xsane-main-window-x-position",             xsane_rc_pref_int, DPOFFSET(dialog_posx)},
+    {"xsane-main-window-y-position",             xsane_rc_pref_int, DPOFFSET(dialog_posy)},
 
-    {"xsane-main-window-width",                  xsane_rc_pref_int, DPOFFSET(shell_width)},
-    {"xsane-main-window-height",                 xsane_rc_pref_int, DPOFFSET(shell_height)},
+    {"xsane-main-window-width",                  xsane_rc_pref_int, DPOFFSET(dialog_width)},
+    {"xsane-main-window-height",                 xsane_rc_pref_int, DPOFFSET(dialog_height)},
 
-    {"xsane-standard-options-window-x-position", xsane_rc_pref_int, DPOFFSET(standard_options_shell_posx)},
-    {"xsane-standard-options-window-y-position", xsane_rc_pref_int, DPOFFSET(standard_options_shell_posy)},
+    {"xsane-project-window-x-position",          xsane_rc_pref_int, DPOFFSET(project_dialog_posx)},
+    {"xsane-project-window-y-position",          xsane_rc_pref_int, DPOFFSET(project_dialog_posy)},
 
-    {"xsane-advanced-options-window-x-position", xsane_rc_pref_int, DPOFFSET(advanced_options_shell_posx)},
-    {"xsane-advanced-options-window-y-position", xsane_rc_pref_int, DPOFFSET(advanced_options_shell_posy)},
+    {"xsane-standard-options-window-x-position", xsane_rc_pref_int, DPOFFSET(standard_options_dialog_posx)},
+    {"xsane-standard-options-window-y-position", xsane_rc_pref_int, DPOFFSET(standard_options_dialog_posy)},
+
+    {"xsane-advanced-options-window-x-position", xsane_rc_pref_int, DPOFFSET(advanced_options_dialog_posx)},
+    {"xsane-advanced-options-window-y-position", xsane_rc_pref_int, DPOFFSET(advanced_options_dialog_posy)},
 
     {"xsane-histogram-window-x-position",        xsane_rc_pref_int, DPOFFSET(histogram_dialog_posx)},
     {"xsane-histogram-window-y-position",        xsane_rc_pref_int, DPOFFSET(histogram_dialog_posy)},
@@ -96,11 +99,14 @@ desc_xsane_device[] =
     {"xsane-threshold-offset",        xsane_rc_pref_double,       DPOFFSET(threshold_off)},
     {"xsane-grayscale-scanmode",      xsane_rc_pref_string,       DPOFFSET(grayscale_scanmode)},
 
-    {"xsane-adf-scansource",          xsane_rc_pref_string,       DPOFFSET(adf_scansource)},
-
     {"xsane-enhancement-rgb-default", xsane_rc_pref_int,          DPOFFSET(enhancement_rgb_default)},
     {"xsane-negative",                xsane_rc_pref_int,          DPOFFSET(negative)},
     {"xsane-show-preview",            xsane_rc_pref_int,          DPOFFSET(show_preview)},
+
+    {"xsane-enable-color-management", xsane_rc_pref_int,          DPOFFSET(enable_color_management)},
+    {"xsane-embed-icm-profile",       xsane_rc_pref_int,          DPOFFSET(embed_icm_profile)},
+    {"xsane-scanner-refl-icm-profile", xsane_rc_pref_string,      DPOFFSET(scanner_refl_icm_profile)},
+    {"xsane-scanner-tran-icm-profile", xsane_rc_pref_string,      DPOFFSET(scanner_tran_icm_profile)},
 };
 
 /* ---------------------------------------------------------------------------------------------------------------- */
@@ -108,7 +114,7 @@ desc_xsane_device[] =
 static int xsane_device_preferences_load_values(Wire *w, SANE_Handle device)
 {
  const SANE_Option_Descriptor *opt;
- SANE_Word *word_array;
+ char *word_array;
  SANE_String name, str;
  u_long *caused_reload;
  SANE_Int num_options;
@@ -192,12 +198,12 @@ static int xsane_device_preferences_load_values(Wire *w, SANE_Handle device)
           }
           else /* array */
           {
-            SANE_Int len;
+           SANE_Int len;
 
-            xsane_rc_io_w_array(w, &len, (void **) &word_array, (WireCodecFunc) xsane_rc_io_w_word, sizeof(SANE_Word));
+            xsane_rc_io_w_array(w, &len, &word_array, (WireCodecFunc) xsane_rc_io_w_word, sizeof(SANE_Word));
             status = xsane_control_option(device, i, SANE_ACTION_SET_VALUE, word_array, &info);
             w->direction = WIRE_FREE;
-            xsane_rc_io_w_array(w, &len, (void **) &word_array, (WireCodecFunc) xsane_rc_io_w_word, sizeof(SANE_Word));
+            xsane_rc_io_w_array(w, &len, &word_array, (WireCodecFunc) xsane_rc_io_w_word, sizeof(SANE_Word));
             w->direction = WIRE_DECODE;
           }
 	  break;
@@ -238,7 +244,7 @@ static int xsane_device_preferences_save_values(Wire *w, SANE_Handle device)
 {
  const SANE_Option_Descriptor *opt;
  size_t word_array_size = 0;
- SANE_Word *word_array = 0;
+ char *word_array = 0;
  size_t str_size = 0;
  SANE_String str = 0;
  SANE_Word word;
@@ -307,7 +313,7 @@ static int xsane_device_preferences_save_values(Wire *w, SANE_Handle device)
           }
 
           xsane_rc_io_w_string(w, (SANE_String *) &opt->name);
-          xsane_rc_io_w_array(w, &len, (void **) &word_array, (WireCodecFunc) xsane_rc_io_w_word, sizeof(SANE_Word));
+          xsane_rc_io_w_array(w, &len, &word_array, (WireCodecFunc) xsane_rc_io_w_word, sizeof(SANE_Word));
         }
         break;
 
@@ -365,7 +371,7 @@ static int xsane_device_preferences_save_values(Wire *w, SANE_Handle device)
 void xsane_device_preferences_load_file(char *filename)
 {
  int fd;
- char buf[256];
+ char buf[TEXTBUFSIZE];
 #if 0
  char *version = 0;
 #endif
@@ -376,30 +382,37 @@ void xsane_device_preferences_load_file(char *filename)
   DBG(DBG_proc, "xsane_device_preferences_load_file\n");
 
   /* set geometry and position to standard values */
-  xsane.shell_posx                  = XSANE_SHELL_POS_X;
-  xsane.shell_posy                  = XSANE_SHELL_POS_Y;
-  xsane.shell_width                 = XSANE_SHELL_WIDTH;
-  xsane.shell_height                = XSANE_SHELL_HEIGHT;
+  xsane.dialog_posx                  = XSANE_DIALOG_POS_X;
+  xsane.dialog_posy                  = XSANE_DIALOG_POS_Y;
+  xsane.dialog_width                 = XSANE_DIALOG_WIDTH;
+  xsane.dialog_height                = XSANE_DIALOG_HEIGHT;
 
-  xsane.standard_options_shell_posx = XSANE_STD_OPTIONS_POS_X;
-  xsane.standard_options_shell_posy = XSANE_STD_OPTIONS_POS_Y;
+  xsane.project_dialog_posx          = XSANE_PROJECT_DIALOG_POS_X;
+  xsane.project_dialog_posy          = XSANE_PROJECT_DIALOG_POS_Y;
 
-  xsane.advanced_options_shell_posx = XSANE_ADV_OPTIONS_POS_X;
-  xsane.advanced_options_shell_posy = XSANE_ADV_OPTIONS_POS_Y;
+  xsane.standard_options_dialog_posx = XSANE_STD_OPTIONS_DIALOG_POS_X;
+  xsane.standard_options_dialog_posy = XSANE_STD_OPTIONS_DIALOG_POS_Y;
 
-  xsane.histogram_dialog_posx       = XSANE_HISTOGRAM_POS_X;
-  xsane.histogram_dialog_posy       = XSANE_HISTOGRAM_POS_Y;
+  xsane.advanced_options_dialog_posx = XSANE_ADV_OPTIONS_DIALOG_POS_X;
+  xsane.advanced_options_dialog_posy = XSANE_ADV_OPTIONS_DIALOG_POS_Y;
 
-  xsane.gamma_dialog_posx           = XSANE_GAMMA_POS_X;
-  xsane.gamma_dialog_posy           = XSANE_GAMMA_POS_Y;
+  xsane.histogram_dialog_posx       = XSANE_HISTOGRAM_DIALOG_POS_X;
+  xsane.histogram_dialog_posy       = XSANE_HISTOGRAM_DIALOG_POS_Y;
 
-  xsane.batch_dialog_posx           = XSANE_BATCH_POS_X;
-  xsane.batch_dialog_posy           = XSANE_BATCH_POS_Y;
+  xsane.gamma_dialog_posx           = XSANE_GAMMA_DIALOG_POS_X;
+  xsane.gamma_dialog_posy           = XSANE_GAMMA_DIALOG_POS_Y;
 
-  xsane.preview_dialog_posx         = XSANE_PREVIEW_POS_X;
-  xsane.preview_dialog_posy         = XSANE_PREVIEW_POS_Y;
-  xsane.preview_dialog_width        = XSANE_PREVIEW_WIDTH;
-  xsane.preview_dialog_height       = XSANE_PREVIEW_HEIGHT;
+  xsane.batch_dialog_posx           = XSANE_BATCH_DIALOG_POS_X;
+  xsane.batch_dialog_posy           = XSANE_BATCH_DIALOG_POS_Y;
+
+  xsane.preview_dialog_posx         = XSANE_PREVIEW_DIALOG_POS_X;
+  xsane.preview_dialog_posy         = XSANE_PREVIEW_DIALOG_POS_Y;
+  xsane.preview_dialog_width        = XSANE_PREVIEW_DIALOG_WIDTH;
+  xsane.preview_dialog_height       = XSANE_PREVIEW_DIALOG_HEIGHT;
+
+  xsane.resolution                  = 1.0;
+  xsane.resolution_x                = 1.0;
+  xsane.resolution_y                = 1.0;
 
   xsane.gamma                       = 1.0;
   xsane.gamma_red                   = 1.0;
@@ -424,12 +437,12 @@ void xsane_device_preferences_load_file(char *filename)
   xsane.threshold_mul               = 1.0;
   xsane.threshold_off               = 0.0;
 
-  xsane.adf_scansource              = 0; /* Empty String => keeps adf scansource */
-
   xsane.enhancement_rgb_default     = 1;
   xsane.negative                    = 0;
   xsane.show_preview                = 1;
 
+  xsane.embed_icm_profile           = 0;
+
   fd = open(filename, O_RDONLY); 
   if (fd >= 0)
   {
@@ -455,7 +468,7 @@ void xsane_device_preferences_load_file(char *filename)
 
     if (w.status)
     {
-      char buf[256];
+      char buf[TEXTBUFSIZE];
 
       snprintf(buf, sizeof(buf), "%s\n%s %s", ERR_LOAD_DEVICE_SETTINGS, filename, ERR_NO_DRC_FILE);
       xsane_back_gtk_error(buf, TRUE);
@@ -552,17 +565,31 @@ void xsane_device_preferences_load_file(char *filename)
       }
     }
   }
-  gtk_window_move(GTK_WINDOW(xsane.shell), xsane.shell_posx, xsane.shell_posy);
-  gtk_window_set_default_size(GTK_WINDOW(xsane.shell), xsane.shell_width, xsane.shell_height);
-  gtk_window_move(GTK_WINDOW(xsane.standard_options_shell), xsane.standard_options_shell_posx, xsane.standard_options_shell_posy);
-  gtk_window_move(GTK_WINDOW(xsane.advanced_options_shell), xsane.advanced_options_shell_posx, xsane.advanced_options_shell_posy);
+  gtk_window_move(GTK_WINDOW(xsane.dialog), xsane.dialog_posx, xsane.dialog_posy);
+  gtk_window_set_default_size(GTK_WINDOW(xsane.dialog), xsane.dialog_width, xsane.dialog_height);
+
+  if (xsane.project_dialog)
+  {
+    gtk_window_move(GTK_WINDOW(xsane.project_dialog), xsane.project_dialog_posx, xsane.project_dialog_posy);
+  }
+
+  gtk_window_move(GTK_WINDOW(xsane.standard_options_dialog), xsane.standard_options_dialog_posx, xsane.standard_options_dialog_posy);
+  gtk_window_move(GTK_WINDOW(xsane.advanced_options_dialog), xsane.advanced_options_dialog_posx, xsane.advanced_options_dialog_posy);
   gtk_window_move(GTK_WINDOW(xsane.histogram_dialog), xsane.histogram_dialog_posx, xsane.histogram_dialog_posy);
 #if 0
   gtk_window_move(GTK_WINDOW(xsane.gamma_dialog), xsane.gamma_dialog_posx, xsane.gamma_dialog_posy);
 #endif
   gtk_window_move(GTK_WINDOW(xsane.batch_scan_dialog), xsane.batch_dialog_posx, xsane.batch_dialog_posy);
   gtk_window_move(GTK_WINDOW(xsane.preview->top), xsane.preview_dialog_posx, xsane.preview_dialog_posy);
+#ifdef HAVE_GTK2
+  gtk_window_resize(GTK_WINDOW(xsane.preview->top), xsane.preview_dialog_width, xsane.preview_dialog_height);
+#else
   gtk_window_set_default_size(GTK_WINDOW(xsane.preview->top), xsane.preview_dialog_width, xsane.preview_dialog_height);
+#endif
+
+#ifdef HAVE_LIBLCMS
+  gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(xsane.enable_color_management_widget), xsane.enable_color_management);
+#endif
 
   xsane_update_param(0);
   xsane_refresh_dialog();
@@ -596,7 +623,7 @@ void xsane_device_preferences_restore(void)
 void xsane_device_preferences_load(void)
 {
  char filename[PATH_MAX];
- char windowname[256];
+ char windowname[TEXTBUFSIZE];
 
   DBG(DBG_proc, "xsane_device_preferences_load\n");
 
@@ -633,7 +660,7 @@ void xsane_device_preferences_save_file(char *filename)
     fd = open(filename, O_WRONLY | O_CREAT | O_TRUNC, 0666);
     if (fd < 0)
     {
-     char buf[256];
+     char buf[TEXTBUFSIZE];
 
       snprintf(buf, sizeof(buf), "%s %s.", ERR_FAILED_CREATE_FILE, strerror(errno));
       xsane_back_gtk_error(buf, TRUE);
@@ -655,34 +682,66 @@ void xsane_device_preferences_save_file(char *filename)
     XSANE_RC_IO_W_STRINGCONST(&w, XSANE_VERSION);
 
     /* make geometry and position values up to date */
-    xsane_window_get_position(xsane.shell, &xsane.shell_posx, &xsane.shell_posy);
-    gdk_drawable_get_size(xsane.shell->window, &xsane.shell_width, &xsane.shell_height);
-    gtk_window_move(GTK_WINDOW(xsane.shell), xsane.shell_posx, xsane.shell_posy); /* geometry used when window closed and opened again */
-    gtk_window_set_default_size(GTK_WINDOW(xsane.shell), xsane.shell_width, xsane.shell_height);
+    xsane_window_get_position(xsane.dialog, &xsane.dialog_posx, &xsane.dialog_posy);
+    gdk_drawable_get_size(xsane.dialog->window, &xsane.dialog_width, &xsane.dialog_height);
+#if 0 /* TO BE REMOVED */
+    gtk_window_move(GTK_WINDOW(xsane.dialog), xsane.dialog_posx, xsane.dialog_posy); /* geometry used when window closed and opened again */
+    gtk_window_set_default_size(GTK_WINDOW(xsane.dialog), xsane.dialog_width, xsane.dialog_height);
+#endif
 
-    xsane_window_get_position(xsane.standard_options_shell, &xsane.standard_options_shell_posx, &xsane.standard_options_shell_posy);
-    gtk_window_move(GTK_WINDOW(xsane.standard_options_shell), xsane.standard_options_shell_posx, xsane.standard_options_shell_posy);
+    if (xsane.project_dialog)
+    {
+      xsane_window_get_position(xsane.project_dialog, &xsane.project_dialog_posx, &xsane.project_dialog_posy);
+#if 0 /* TO BE REMOVED */
+      gtk_window_move(GTK_WINDOW(xsane.project_dialog), xsane.project_dialog_posx, xsane.project_dialog_posy);
+#endif
+    }
 
-    xsane_window_get_position(xsane.advanced_options_shell, &xsane.advanced_options_shell_posx, &xsane.advanced_options_shell_posy);
-    gtk_window_move(GTK_WINDOW(xsane.advanced_options_shell), xsane.advanced_options_shell_posx, xsane.advanced_options_shell_posy);
+    if (preferences.show_standard_options)
+    {
+      xsane_window_get_position(xsane.standard_options_dialog, &xsane.standard_options_dialog_posx, &xsane.standard_options_dialog_posy);
+#if 0 /* TO BE REMOVED */
+      gtk_window_move(GTK_WINDOW(xsane.standard_options_dialog), xsane.standard_options_dialog_posx, xsane.standard_options_dialog_posy);
+#endif
+    }
 
-    xsane_window_get_position(xsane.histogram_dialog, &xsane.histogram_dialog_posx, &xsane.histogram_dialog_posy);
-    gtk_window_move(GTK_WINDOW(xsane.histogram_dialog), xsane.histogram_dialog_posx, xsane.histogram_dialog_posy);
+    if (preferences.show_advanced_options)
+    {
+      xsane_window_get_position(xsane.advanced_options_dialog, &xsane.advanced_options_dialog_posx, &xsane.advanced_options_dialog_posy);
+#if 0 /* TO BE REMOVED */
+      gtk_window_move(GTK_WINDOW(xsane.advanced_options_dialog), xsane.advanced_options_dialog_posx, xsane.advanced_options_dialog_posy);
+#endif
+    }
+
+    if (preferences.show_histogram)
+    {
+      xsane_window_get_position(xsane.histogram_dialog, &xsane.histogram_dialog_posx, &xsane.histogram_dialog_posy);
+#if 0 /* TO BE REMOVED */
+      gtk_window_move(GTK_WINDOW(xsane.histogram_dialog), xsane.histogram_dialog_posx, xsane.histogram_dialog_posy);
+#endif
+    }
 
 #if 0
     xsane_window_get_position(xsane.gamma_dialog, &xsane.gamma_dialog_posx, &xsane.gamma_dialog_posy);
     gtk_window_move(GTK_WINDOW(xsane.gamma_dialog), xsane.gamma_dialog_posx, xsane.gamma_dialog_posy);
 #endif
 
-    xsane_window_get_position(xsane.batch_scan_dialog, &xsane.batch_dialog_posx, &xsane.batch_dialog_posy);
-    gtk_window_move(GTK_WINDOW(xsane.batch_scan_dialog), xsane.batch_dialog_posx, xsane.batch_dialog_posy);
+    if (preferences.show_batch_scan)
+    {
+      xsane_window_get_position(xsane.batch_scan_dialog, &xsane.batch_dialog_posx, &xsane.batch_dialog_posy);
+#if 0 /* TO BE REMOVED */
+      gtk_window_move(GTK_WINDOW(xsane.batch_scan_dialog), xsane.batch_dialog_posx, xsane.batch_dialog_posy);
+#endif
+    }
 
     if (xsane.preview)
     {
       xsane_window_get_position(xsane.preview->top, &xsane.preview_dialog_posx, &xsane.preview_dialog_posy);
       gdk_drawable_get_size(xsane.preview->top->window, &xsane.preview_dialog_width, &xsane.preview_dialog_height);
+#if 0
       gtk_window_move(GTK_WINDOW(xsane.preview->top), xsane.preview_dialog_posx, xsane.preview_dialog_posy);
       gtk_window_set_default_size(GTK_WINDOW(xsane.preview->top), xsane.preview_dialog_width, xsane.preview_dialog_height);
+#endif
     }
 
     xsane_device_preferences_save_values(&w, xsane.dev);
@@ -715,7 +774,7 @@ void xsane_device_preferences_store(void)
 void xsane_device_preferences_save(void)
 {
  char filename[PATH_MAX];
- char windowname[256];
+ char windowname[TEXTBUFSIZE];
 
   DBG(DBG_proc, "xsane_device_preferences_save\n");
 
