@@ -3,7 +3,7 @@
    xsane-front-gtk.c
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2005 Oliver Rauch
+   Copyright (C) 1998-2007 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 
 #include "xsane.h"
 #include "xsane-back-gtk.h"
+#include "xsane-front-gtk.h"
 #include "xsane-preferences.h"
 #include "xsane-preview.h"
 #include "xsane-save.h"
@@ -66,14 +67,14 @@ void xsane_option_menu_new(GtkWidget *parent, char *str_list[], const char *val,
                            void *option_menu_callback, SANE_Int settable, const gchar *widget_name);
 void xsane_option_menu_new_with_pixmap(GdkWindow *window, GtkBox *parent, const char *xpm_d[], const char *desc,
                                        char *str_list[], const char *val,
-                                       GtkObject **data, int option,
+                                       GtkWidget **data, int option,
                                        void *option_menu_callback, SANE_Int settable, const gchar *widget_name);
 void xsane_range_new(GtkBox *parent, char *labeltext, const char *desc,
                      float min, float max, float quant, float page_step,
-                     int digits, double *val, GtkObject **data, void *xsane_range_callback, SANE_Int settable);
+                     int digits, double *val, GtkWidget **data, void *xsane_range_callback, SANE_Int settable);
 void xsane_range_new_with_pixmap(GdkWindow *window, GtkBox *parent, const char *xpm_d[], const char *desc,
                                  float min, float max, float quant, float page_step, int digits,
-                                 double *val, GtkObject **data, int option, void *xsane_range_callback, SANE_Int settable);
+                                 double *val, GtkWidget **data, int option, void *xsane_range_callback, SANE_Int settable);
 static void xsane_outputfilename_changed_callback(GtkWidget *widget, gpointer data);
 void xsane_set_filename(gchar *filename);
 void xsane_separator_new(GtkWidget *xsane_parent, int dist);
@@ -92,7 +93,7 @@ int xsane_parse_options(char *options, char *argv[])
  int optpos = 0;
  int bufpos = 0;
  int arg    = 0;
- char buf[256];
+ char buf[TEXTBUFSIZE];
  
   DBG(DBG_proc, "xsane_parse_options\n");
  
@@ -170,11 +171,11 @@ void xsane_get_bounds(const SANE_Option_Descriptor *opt, double *minp, double *m
   {
     if (min > -INF && min < INF)
     {
-      min = SANE_UNFIX (min);
+      min = SANE_UNFIX(min);
     }
     if (max > -INF && max < INF)
     {
-      max = SANE_UNFIX (max);
+      max = SANE_UNFIX(max);
     }
   }
   *minp = min;
@@ -355,9 +356,18 @@ void xsane_set_all_resolutions(void)
   if (new_resolution < 0) /* set y resolution not possible */
   {
     new_resolution = xsane_set_resolution(xsane.well_known.dpi, xsane.resolution); /* set common resolution if necessary */
-    xsane.resolution   = new_resolution;
-    xsane.resolution_x = new_resolution;
-    xsane.resolution_y = new_resolution;
+    if (new_resolution > 0)
+    {
+      xsane.resolution   = new_resolution;
+      xsane.resolution_x = new_resolution;
+      xsane.resolution_y = new_resolution;
+    }
+    else
+    {
+      xsane.resolution   = 72.0;
+      xsane.resolution_x = 72.0;
+      xsane.resolution_y = 72.0;
+    }
   }
   else /* we were able to set y resolution */
   {
@@ -387,10 +397,6 @@ void xsane_set_all_resolutions(void)
       printer_resolution = preferences.printer[preferences.printernr]->color_resolution;
      break;
   }
-
-  xsane.zoom   = xsane.resolution   / printer_resolution;
-  xsane.zoom_x = xsane.resolution_x / printer_resolution;
-  xsane.zoom_y = xsane.resolution_y / printer_resolution; 
 }
 
 /* ---------------------------------------------------------------------------------------------------------------------- */
@@ -405,7 +411,7 @@ void xsane_define_maximum_output_size()
 
   if ( (opt) && (opt->unit== SANE_UNIT_MM) )
   {
-    switch(preferences.xsane_mode)
+    switch(xsane.xsane_mode)
     {
       case XSANE_SAVE:
 
@@ -423,15 +429,15 @@ void xsane_define_maximum_output_size()
         if (preferences.paper_orientation >= 8) /* rotate: landscape */
         {
           preview_set_maximum_output_size(xsane.preview,
-                                          preferences.printer[preferences.printernr]->height / xsane.zoom_y,
-                                          preferences.printer[preferences.printernr]->width  / xsane.zoom_x,
+                                          preferences.printer[preferences.printernr]->height / xsane.zoom,
+                                          preferences.printer[preferences.printernr]->width  / xsane.zoom,
                                           preferences.paper_orientation);
         }
         else /* do not rotate: portrait */
         {
           preview_set_maximum_output_size(xsane.preview,
-                                          preferences.printer[preferences.printernr]->width  / xsane.zoom_x,
-                                          preferences.printer[preferences.printernr]->height / xsane.zoom_y,
+                                          preferences.printer[preferences.printernr]->width  / xsane.zoom,
+                                          preferences.printer[preferences.printernr]->height / xsane.zoom,
                                           preferences.paper_orientation);
         }
        break;
@@ -440,7 +446,7 @@ void xsane_define_maximum_output_size()
         preview_set_maximum_output_size(xsane.preview, preferences.fax_width, preferences.fax_height, 0);
        break;
 
-      case XSANE_MAIL:
+      case XSANE_EMAIL:
         preview_set_maximum_output_size(xsane.preview, INF, INF, 0);
        break;
 
@@ -1026,7 +1032,7 @@ void xsane_option_menu_new(GtkWidget *parent, char *str_list[], const char *val,
 
 void xsane_option_menu_new_with_pixmap(GdkWindow *window, GtkBox *parent, const char *xpm_d[], const char *desc,
                                        char *str_list[], const char *val,
-                                       GtkObject **data, int option,
+                                       GtkWidget **data, int option,
                                        void *option_menu_callback, SANE_Int settable, const gchar *widget_name)
 {
  GtkWidget *hbox;
@@ -1052,7 +1058,7 @@ void xsane_option_menu_new_with_pixmap(GdkWindow *window, GtkBox *parent, const
 
 static void xsane_range_display_value_right_callback(GtkAdjustment *adjust, gpointer data)
 {
- gchar buf[256];
+ gchar buf[TEXTBUFSIZE];
  int digits = (int) data;
  GtkLabel *label;
 
@@ -1065,7 +1071,7 @@ static void xsane_range_display_value_right_callback(GtkAdjustment *adjust, gpoi
 
 void xsane_range_new(GtkBox *parent, char *labeltext, const char *desc,
                      float min, float max, float quant, float page_step,
-                     int digits, double *val, GtkObject **data, void *xsane_range_callback, SANE_Int settable)
+                     int digits, double *val, GtkWidget **data, void *xsane_range_callback, SANE_Int settable)
 {
  GtkWidget *hbox;
  GtkWidget *label;
@@ -1081,7 +1087,7 @@ void xsane_range_new(GtkBox *parent, char *labeltext, const char *desc,
   label = gtk_label_new(labeltext);
   gtk_box_pack_start(GTK_BOX(hbox), label, FALSE, FALSE, 1);
 
-  *data = gtk_adjustment_new(*val, min, max, quant, page_step, (max-min) * 1e-30);
+  *data = (GtkWidget *) gtk_adjustment_new(*val, min, max, quant, page_step, (max-min) * 1e-30);
   /* 1e-30 => hscrollbar has an unwanted side effect: the maximum is not the maximum */
   /* of the given range, it is reduced by the page_size, so it has to be very small */
 
@@ -1153,7 +1159,7 @@ void xsane_range_new(GtkBox *parent, char *labeltext, const char *desc,
 
 void xsane_range_new_with_pixmap(GdkWindow *window, GtkBox *parent, const char *xpm_d[], const char *desc,
                                  float min, float max, float quant, float page_step,
-                                 int digits, double *val, GtkObject **data, int option, void *xsane_range_callback, SANE_Int settable)
+                                 int digits, double *val, GtkWidget **data, int option, void *xsane_range_callback, SANE_Int settable)
 {
  GtkWidget *hbox;
  GtkWidget *slider = NULL;
@@ -1174,7 +1180,7 @@ void xsane_range_new_with_pixmap(GdkWindow *window, GtkBox *parent, const char *
   gtk_widget_show(pixmapwidget);
   gdk_drawable_unref(pixmap);
 
-  *data = gtk_adjustment_new(*val, min, max, quant, page_step, (max-min) * 1e-30);
+  *data = (GtkWidget *) gtk_adjustment_new(*val, min, max, quant, page_step, (max-min) * 1e-30);
   /* 1e-30 => hscrollbar has an unwanted side effect: the maximum is not the maximum */
   /* of the given range, it is reduced by the page_size, so it has to be very small */
 
@@ -1245,7 +1251,7 @@ void xsane_range_new_with_pixmap(GdkWindow *window, GtkBox *parent, const char *
    DialogElement *elem;
 
     elem=xsane.element + option;
-    elem->data    = *data;
+    elem->data    = (GtkObject *) *data;
     elem->widget  = slider;
   }
 }
@@ -1254,8 +1260,8 @@ void xsane_range_new_with_pixmap(GdkWindow *window, GtkBox *parent, const char *
 
 static void xsane_browse_filename_callback(GtkWidget *widget, gpointer data)
 {
- char filename[1024];
- char windowname[256];
+ char filename[PATH_MAX];
+ char windowname[TEXTBUFSIZE];
 
   DBG(DBG_proc, "xsane_browse_filename_callback\n");
 
@@ -1395,6 +1401,9 @@ void xsane_outputfilename_new(GtkWidget *vbox)
  GtkWidget *xsane_filename_counter_step_menu;
  GtkWidget *xsane_filename_counter_step_item;
  GtkWidget *xsane_label;
+ GtkWidget *pixmapwidget;
+ GdkBitmap *mask;
+ GdkPixmap *pixmap;
  gchar buf[200];
  int i,j;
  int select_item = 0;
@@ -1431,13 +1440,15 @@ void xsane_outputfilename_new(GtkWidget *vbox)
 
   hbox = gtk_hbox_new(FALSE, 2);
   gtk_container_set_border_width(GTK_CONTAINER(hbox), 2);
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 2);
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, FALSE, 1);
 
   /* filename counter step */
- 
-  xsane_label = gtk_label_new(TEXT_FILENAME_COUNTER_STEP);
-  gtk_box_pack_start(GTK_BOX(hbox), xsane_label, FALSE, FALSE, 2);
-  gtk_widget_show(xsane_label);
+
+  pixmap = gdk_pixmap_create_from_xpm_d(xsane.xsane_window->window, &mask, xsane.bg_trans, (gchar **) step_xpm);
+  pixmapwidget = gtk_image_new_from_pixmap(pixmap, mask);
+  gtk_box_pack_start(GTK_BOX(hbox), pixmapwidget, FALSE, FALSE, 2);
+  gtk_widget_show(pixmapwidget);
+  gdk_drawable_unref(pixmap);
  
   xsane_filename_counter_step_option_menu = gtk_option_menu_new();
   xsane_back_gtk_set_tooltip(xsane.tooltips, xsane_filename_counter_step_option_menu, DESC_FILENAME_COUNTER_STEP);
@@ -1688,7 +1699,7 @@ int xsane_identify_output_format(char *filename, char *filetype, char **ext)
 
   DBG(DBG_proc, "xsane_identify_output_format\n");
 
-  if ((filetype) && (*filetype))
+  if ((filetype) && (*filetype) && (!xsane.force_filename))
   {
     extension = filetype+1; /* go to filetype, skip leading dot */
   }
@@ -1777,7 +1788,7 @@ int xsane_identify_output_format(char *filename, char *filetype, char **ext)
 void xsane_change_working_directory(void)
 {
  char filename[PATH_MAX];
- char windowname[256];
+ char windowname[TEXTBUFSIZE];
 
   DBG(DBG_proc, "xsane_change_working_directory\n");
 
@@ -1789,7 +1800,7 @@ void xsane_change_working_directory(void)
     xsane_back_gtk_get_filename(windowname, filename, sizeof(filename), filename, NULL, TRUE, FALSE, TRUE, FALSE);
     if (chdir(filename))
     {
-     char buf[256];
+     char buf[TEXTBUFSIZE];
 
       snprintf(buf, sizeof(buf), "%s %s (%s).", ERR_CHANGE_WORKING_DIR, filename, strerror(errno));
       xsane_back_gtk_error(buf, TRUE);
@@ -1896,7 +1907,7 @@ int xsane_display_eula(int ask_for_accept)
                              XSANE_COPYRIGHT_SIGN, XSANE_COPYRIGHT_TXT,
                              TEXT_EULA,
                              TEXT_HOMEPAGE, XSANE_HOMEPAGE,
-                             TEXT_EMAIL, XSANE_EMAIL);
+                             TEXT_EMAIL_ADR, XSANE_EMAIL_ADR);
 
   label = gtk_label_new(buf);
   gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
@@ -2140,7 +2151,7 @@ void xsane_display_gpl(void)
                              XSANE_COPYRIGHT_SIGN, XSANE_COPYRIGHT_TXT,
                              TEXT_GPL,
                              TEXT_HOMEPAGE, XSANE_HOMEPAGE,
-                             TEXT_EMAIL, XSANE_EMAIL);
+                             TEXT_EMAIL_ADR, XSANE_EMAIL_ADR);
 
   label = gtk_label_new(buf);
   gtk_box_pack_start(GTK_BOX(vbox), label, FALSE, FALSE, 0);
@@ -2347,7 +2358,7 @@ int xsane_front_gtk_getname_dialog(const char *dialog_title, const char *desc_te
  GtkWidget *button;
  GtkWidget *vbox, *hbox;
  GtkAccelGroup *accelerator_group;
- char buf[256];
+ char buf[TEXTBUFSIZE];
                                                                                                                                  
   DBG(DBG_proc, "xsane_getname_dialog, oldname = %s\n", oldname);
                                                                                                                                  
@@ -2432,24 +2443,105 @@ int xsane_front_gtk_getname_dialog(const char *dialog_title, const char *desc_te
 }
                                                                                                                                  
 /* ---------------------------------------------------------------------------------------------------------------------- */
-#ifdef XSANE_ACTIVATE_MAIL
-void xsane_front_gtk_mail_project_update_lockfile_status()
+
+void xsane_front_gtk_list_entries_swap(GtkWidget *list_item_1, GtkWidget *list_item_2)
+{
+ char *page1;
+ char *page2;
+ char *type1;
+ char *type2;
+
+  DBG(DBG_proc, "xsane_front_gtk_list_entries_swap\n");
+
+  page1 = (char *) gtk_object_get_data(GTK_OBJECT(list_item_1), "list_item_data");
+  type1 = (char *) gtk_object_get_data(GTK_OBJECT(list_item_1), "list_item_type");
+  page2 = (char *) gtk_object_get_data(GTK_OBJECT(list_item_2), "list_item_data");
+  type2 = (char *) gtk_object_get_data(GTK_OBJECT(list_item_2), "list_item_type");
+
+  gtk_label_set(GTK_LABEL(gtk_container_children(GTK_CONTAINER(list_item_1))->data), page2);
+  gtk_label_set(GTK_LABEL(gtk_container_children(GTK_CONTAINER(list_item_2))->data), page1);
+  gtk_object_set_data(GTK_OBJECT(list_item_1), "list_item_data", page2);
+  gtk_object_set_data(GTK_OBJECT(list_item_1), "list_item_type", type2);
+  gtk_object_set_data(GTK_OBJECT(list_item_2), "list_item_data", page1);
+  gtk_object_set_data(GTK_OBJECT(list_item_2), "list_item_type", type1);
+}
+
+/* ---------------------------------------------------------------------------------------------------------------------- */
+
+void xsane_front_gtk_add_process_to_list(pid_t pid)
+{
+ XsaneChildprocess *newprocess;
+ 
+  DBG(DBG_proc, "xsane_front_gtk_add_process_to_list(%d)\n", pid);
+ 
+  newprocess = malloc(sizeof(XsaneChildprocess));
+  newprocess->pid = pid;
+  newprocess->next = xsane.childprocess_list;
+  xsane.childprocess_list = newprocess;
+} 
+
+/* ---------------------------------------------------------------------------------------------------------------------- */
+
+int xsane_front_gtk_option_defined(char *string)
+{
+  if (string)
+  {
+    while (*string == ' ') /* skip spaces */
+    {
+      string++;
+    }
+    if (*string != 0)
+    {
+      return 1;
+    }
+  }
+  return 0;
+}
+
+/* ---------------------------------------------------------------------------------------------------------------------- */
+#ifdef XSANE_ACTIVATE_EMAIL
+void xsane_front_gtk_email_project_update_lockfile_status()
 {
  FILE *lockfile;
  char filename[PATH_MAX];
 
-  snprintf(filename, sizeof(filename), "%s/lockfile", preferences.mail_project);
+  snprintf(filename, sizeof(filename), "%s/lockfile", preferences.email_project);
   lockfile = fopen(filename, "wb");
 
   if (lockfile)
   {
-    fprintf(lockfile, "%s\n", xsane.mail_status); /* first line is status of mail */
-    fprintf(lockfile, "%3d\n", (int) (xsane.mail_progress_val * 100));
+    fprintf(lockfile, "%s\n", xsane.email_status); /* first line is status of mail */
+    fprintf(lockfile, "%3d\n", (int) (xsane.email_progress_val * 100));
   }
 
   fclose(lockfile);
 }
 #endif
 /* ---------------------------------------------------------------------------------------------------------------------- */
+
+void xsane_project_dialog_close()
+{
+  DBG(DBG_proc, "xsane_project_dialog_close\n");
+                                                                                
+  if (xsane.project_dialog == NULL)
+  {
+    return;
+  }
+
+  if (xsane.project_dialog)
+  {
+    xsane_window_get_position(xsane.project_dialog, &xsane.project_dialog_posx, &xsane.project_dialog_posy);
+    gtk_window_move(GTK_WINDOW(xsane.project_dialog), xsane.project_dialog_posx, xsane.project_dialog_posy);
+  }
+                                                                                
+  gtk_widget_destroy(xsane.project_dialog);
+                                                                                
+  xsane.project_dialog = NULL;
+  xsane.project_list = NULL;
+  xsane.project_progress_bar = NULL;
+}
+
+/* ---------------------------------------------------------------------------------------------------------------------- */
                                                                                                                   
                                                                                                                                  
+
