@@ -3,7 +3,7 @@
    xsane-text.h
 
    Oliver Rauch <Oliver.Rauch@rauch-domain.de>
-   Copyright (C) 1998-2005 Oliver Rauch
+   Copyright (C) 1998-2007 Oliver Rauch
    This file is part of the XSANE package.
 
    This program is free software; you can redistribute it and/or modify
@@ -26,182 +26,190 @@
 #define XSANE_TEXT_H
 
 /* Please translate this to the correct directory name (eg. german=>de) */
-#define XSANE_LANGUAGE_DIR		_("language_dir")
+#define XSANE_LANGUAGE_DIR				_("language_dir")
 
-#define XSANE_STRSTATUS(status)		_(sane_strstatus(status))
-#define _BGT(text)			dgettext(xsane.backend_translation, text)
+#define XSANE_STRSTATUS(status)				_(sane_strstatus(status))
+#define _BGT(text)					dgettext(xsane.backend_translation, text)
 
-#define XSANE_COPYRIGHT_SIGN		_("(c)") /* can be translated with \251 */
+#define XSANE_COPYRIGHT_SIGN				_("(c)") /* can be translated with \251 */
 
-#define FILENAME_PREFIX_CLONE_OF	_("clone-of-")
+#define FILENAME_PREFIX_CLONE_OF			_("clone-of-")
 
-#define WINDOW_ABOUT_XSANE		_("About")
-#define WINDOW_ABOUT_TRANSLATION	_("About translation")
-#define WINDOW_AUTHORIZE		_("authorization")
-#define WINDOW_GPL			_("GPL - the license")
-#define WINDOW_EULA			_("End User License Agreement")
-#define WINDOW_INFO			_("info")
-#define WINDOW_LOAD_BATCH_LIST		_("load batch list")
-#define WINDOW_SAVE_BATCH_LIST		_("save batch list")
-#define WINDOW_BATCH_SCAN		_("batch scan")
-#define WINDOW_BATCH_RENAME		_("rename batch area")
-#define WINDOW_FAX_PROJECT		_("fax project")
-#define WINDOW_FAX_RENAME		_("rename fax page")
-#define WINDOW_FAX_INSERT		_("insert ps-file into fax")
-#define WINDOW_EMAIL_PROJECT		_("E-mail project")
-#define WINDOW_EMAIL_RENAME		_("rename e-mail image")
-#define WINDOW_EMAIL_INSERT		_("insert file into e-mail")
-#define WINDOW_MULTIPAGE_PROJECT	_("multipage project")
-#define WINDOW_PRESET_AREA_RENAME	_("rename preset area")
-#define WINDOW_PRESET_AREA_ADD		_("add preset area")
-#define WINDOW_MEDIUM_RENAME		_("rename medium")
-#define WINDOW_MEDIUM_ADD		_("add new medium")
-#define WINDOW_SETUP			_("setup")
-#define WINDOW_HISTOGRAM		_("Histogram")
-#define WINDOW_GAMMA			_("Gamma curve")
-#define WINDOW_STANDARD_OPTIONS		_("Standard options")
-#define WINDOW_ADVANCED_OPTIONS		_("Advanced options")
-#define WINDOW_DEVICE_SELECTION		_("device selection")
-#define WINDOW_PREVIEW			_("Preview")
-#define WINDOW_VIEWER			_("Viewer")
-#define WINDOW_VIEWER_OUTPUT_FILENAME	_("Viewer: select output filename")
-#define WINDOW_OCR_OUTPUT_FILENAME	_("Select output filename for OCR text file")
-#define WINDOW_OUTPUT_FILENAME		_("select output filename")
-#define WINDOW_SAVE_SETTINGS		_("save device settings")
-#define WINDOW_LOAD_SETTINGS		_("load device settings")
-#define WINDOW_CHANGE_WORKING_DIR	_("change working directory")
-#define WINDOW_TMP_PATH			_("select temporary directory")
-#define WINDOW_SCALE			_("Scale image")
-#define WINDOW_DESPECKLE		_("Despeckle image")
-#define WINDOW_BLUR			_("Blur image")
-#define WINDOW_STORE_MEDIUM		_("Store medium definition")
-#define WINDOW_NO_DEVICES		_("No devices available")
+#define WINDOW_ABOUT_XSANE				_("About")
+#define WINDOW_ABOUT_TRANSLATION			_("About translation")
+#define WINDOW_AUTHORIZE				_("authorization")
+#define WINDOW_GPL					_("GPL - the license")
+#define WINDOW_EULA					_("End User License Agreement")
+#define WINDOW_INFO					_("info")
+#define WINDOW_LOAD_BATCH_LIST				_("load batch list")
+#define WINDOW_SAVE_BATCH_LIST				_("save batch list")
+#define WINDOW_BATCH_SCAN				_("batch scan")
+#define WINDOW_BATCH_RENAME				_("rename batch area")
+#define WINDOW_FAX_PROJECT				_("fax project")
+#define WINDOW_FAX_RENAME				_("rename fax page")
+#define WINDOW_FAX_INSERT				_("insert ps-file into fax")
+#define WINDOW_EMAIL_PROJECT				_("E-mail project")
+#define WINDOW_EMAIL_RENAME				_("rename e-mail image")
+#define WINDOW_EMAIL_INSERT				_("insert file into e-mail")
+#define WINDOW_MULTIPAGE_PROJECT			_("multipage project")
+#define WINDOW_PRESET_AREA_RENAME			_("rename preset area")
+#define WINDOW_PRESET_AREA_ADD				_("add preset area")
+#define WINDOW_MEDIUM_RENAME				_("rename medium")
+#define WINDOW_MEDIUM_ADD				_("add new medium")
+#define WINDOW_SETUP					_("setup")
+#define WINDOW_HISTOGRAM				_("Histogram")
+#define WINDOW_GAMMA					_("Gamma curve")
+#define WINDOW_STANDARD_OPTIONS				_("Standard options")
+#define WINDOW_ADVANCED_OPTIONS				_("Advanced options")
+#define WINDOW_DEVICE_SELECTION				_("device selection")
+#define WINDOW_PREVIEW					_("Preview")
+#define WINDOW_VIEWER					_("Viewer")
+#define WINDOW_VIEWER_OUTPUT_FILENAME			_("Viewer: select output filename")
+#define WINDOW_OCR_OUTPUT_FILENAME			_("Select output filename for OCR text file")
+#define WINDOW_OUTPUT_FILENAME				_("select output filename")
+#define WINDOW_SAVE_SETTINGS				_("save device settings")
+#define WINDOW_LOAD_SETTINGS				_("load device settings")
+#define WINDOW_CHANGE_WORKING_DIR			_("change working directory")
+#define WINDOW_TMP_PATH					_("select temporary directory")
+#define WINDOW_SCALE					_("Scale image")
+#define WINDOW_DESPECKLE				_("Despeckle image")
+#define WINDOW_BLUR					_("Blur image")
+#define WINDOW_STORE_MEDIUM				_("Store medium definition")
+#define WINDOW_NO_DEVICES				_("No devices available")
+#define WINDOW_SCANNER_REFL_ICM_PROFILE			_("select scanner reflective ICM-profile")
+#define WINDOW_SCANNER_TRAN_ICM_PROFILE			_("select scanner transmissive ICM-profile")
+#define WINDOW_DISPLAY_ICM_PROFILE			_("select display ICM-profile")
+#define WINDOW_CUSTOM_PROOFING_ICM_PROFILE		_("select custom proofing ICM-profile")
+#define WINDOW_PRINTER_ICM_PROFILE			_("select printer ICM-profile")
 
-#define MENU_FILE			_("File")
-#define MENU_PREFERENCES		_("Preferences")
-#define MENU_VIEW			_("View")
-#define MENU_WINDOW			_("Window")
-#define MENU_HELP			_("Help")
-#define MENU_EDIT			_("Edit")
-#define MENU_FILTERS			_("Filters")
-#define MENU_GEOMETRY			_("Geometry")
+#define MENU_FILE					_("File")
+#define MENU_PREFERENCES				_("Preferences")
+#define MENU_VIEW					_("View")
+#define MENU_WINDOW					_("Window")
+#define MENU_HELP					_("Help")
+#define MENU_EDIT					_("Edit")
+#define MENU_FILTERS					_("Filters")
+#define MENU_GEOMETRY					_("Geometry")
+#define MENU_COLOR_MANAGEMENT				_("Color management")
 
-#define MENU_ITEM_ABOUT_XSANE		_("About XSane")
-#define MENU_ITEM_ABOUT_TRANSLATION	_("About translation")
-#define MENU_ITEM_INFO			_("Info")
-#define MENU_ITEM_QUIT			_("Quit")
+#define MENU_ITEM_ABOUT_XSANE				_("About XSane")
+#define MENU_ITEM_ABOUT_TRANSLATION			_("About translation")
+#define MENU_ITEM_INFO					_("Info")
+#define MENU_ITEM_QUIT					_("Quit")
 
-#define MENU_ITEM_SAVE_IMAGE		_("Save image")
-#define MENU_ITEM_OCR			_("OCR - save as text")
-#define MENU_ITEM_CLONE			_("Clone")
-#define MENU_ITEM_SCALE			_("Scale")
-#define MENU_ITEM_CLOSE			_("Close")
+#define MENU_ITEM_SAVE_IMAGE				_("Save image")
+#define MENU_ITEM_OCR					_("OCR - save as text")
+#define MENU_ITEM_CLONE					_("Clone")
+#define MENU_ITEM_SCALE					_("Scale")
+#define MENU_ITEM_CLOSE					_("Close")
+	
+#define MENU_ITEM_UNDO					_("Undo")
 
-#define MENU_ITEM_UNDO			_("Undo")
+#define MENU_ITEM_DESPECKLE				_("Despeckle")
+#define MENU_ITEM_BLUR					_("Blur")
+		
+#define MENU_ITEM_ROTATE90				_("Rotate 90")
+#define MENU_ITEM_ROTATE180				_("Rotate 180")
+#define MENU_ITEM_ROTATE270				_("Rotate 270")
+#define MENU_ITEM_MIRROR_X				_("Mirror |")
+#define MENU_ITEM_MIRROR_Y				_("Mirror -")
 
-#define MENU_ITEM_DESPECKLE		_("Despeckle")
-#define MENU_ITEM_BLUR			_("Blur")
+#define FRAME_RAW_IMAGE					_("Raw image")
+#define FRAME_ENHANCED_IMAGE				_("Enhanced image")
 
-#define MENU_ITEM_ROTATE90		_("Rotate 90")
-#define MENU_ITEM_ROTATE180		_("Rotate 180")
-#define MENU_ITEM_ROTATE270		_("Rotate 270")
-#define MENU_ITEM_MIRROR_X		_("Mirror |")
-#define MENU_ITEM_MIRROR_Y		_("Mirror -")
+#define BUTTON_SCAN					_("Scan")
+#define BUTTON_OK					_("Ok")
+#define BUTTON_ACCEPT					_("Accept")
+#define BUTTON_NOT_ACCEPT				_("Not accept")
+#define BUTTON_APPLY					_("Apply")
+#define BUTTON_CANCEL					_("Cancel")
+#define BUTTON_REDUCE					_("Reduce")
+#define BUTTON_CONT_AT_OWN_RISK				_("Continue at your own risk")
+#define BUTTON_BROWSE					_("Browse")
+#define BUTTON_CLOSE					_("Close")
+#define BUTTON_HELP					_("Help")
+#define BUTTON_OVERWRITE				_("Overwrite")
+#define BUTTON_BATCH_LIST_SCAN				_("Scan batch list")
+#define BUTTON_BATCH_AREA_SCAN				_("Scan selected area")
+#define BUTTON_PAGE_DELETE				_("Delete page")
+#define BUTTON_PAGE_SHOW				_("Show page")
+#define BUTTON_PAGE_RENAME				_("Rename page")
+#define BUTTON_IMAGE_DELETE				_("Delete image")
+#define BUTTON_IMAGE_SHOW				_("Show image")
+#define BUTTON_IMAGE_EDIT				_("Edit image")
+#define BUTTON_IMAGE_RENAME				_("Rename image")
+#define BUTTON_FILE_INSERT				_("Insert file")
+#define BUTTON_CREATE_PROJECT				_("Create project")
+#define BUTTON_SEND_PROJECT				_("Send project")
+#define BUTTON_SAVE_MULTIPAGE				_("Save multipage file")
+#define BUTTON_DELETE_PROJECT				_("Delete project")
+#define BUTTON_ADD_PRINTER				_("Add printer")
+#define BUTTON_DELETE_PRINTER				_("Delete printer")
+#define BUTTON_PREVIEW_ACQUIRE				_("Acquire preview")
+#define BUTTON_PREVIEW_CANCEL				_("Cancel preview")
+#define BUTTON_DISCARD_IMAGE				_("Discard image")
+#define BUTTON_DISCARD_ALL_IMAGES			_("Discard all images")
+#define BUTTON_DO_NOT_CLOSE				_("Do not close")
+#define BUTTON_SCALE_BIND				_("Bind scale")
 
-#define FRAME_RAW_IMAGE			_("Raw image")
-#define FRAME_ENHANCED_IMAGE		_("Enhanced image")
+#define RADIO_BUTTON_FINE_MODE				_("Fine mode")
+#define RADIO_BUTTON_HTML_EMAIL				_("HTML e-mail")
+#define RADIO_BUTTON_SAVE_DEVPREFS_AT_EXIT		_("Save device preferences at exit")
+#define RADIO_BUTTON_OVERWRITE_WARNING			_("Overwrite warning")
+#define RADIO_BUTTON_SKIP_EXISTING_NRS			_("Skip existing filenames")
+#define RADIO_BUTTON_SAVE_PS_FLATDECODED		_("Save postscript zlib compressed (ps level 3)")
+#define RADIO_BUTTON_SAVE_PDF_FLATDECODED		_("Save PDF zlib compressed")
+#define RADIO_BUTTON_SAVE_PNM16_AS_ASCII		_("Save 16bit pnm in ascii format")
+#define RADIO_BUTTON_REDUCE_16BIT_TO_8BIT		_("Reduce 16 bit image to 8 bit")
+#define RADIO_BUTTON_WINDOW_FIXED			_("Main window size fixed")
+#define RADIO_BUTTON_DISABLE_GIMP_PREVIEW_GAMMA		_("Disable gimp preview gamma")
+#define RADIO_BUTTON_PRIVATE_COLORMAP			_("Use private colormap")
+#define RADIO_BUTTON_AUTOENHANCE_GAMMA  		_("Autoenhance gamma")
+#define RADIO_BUTTON_PRESELECT_SCANAREA 		_("Preselect scanarea")
+#define RADIO_BUTTON_AUTOCORRECT_COLORS 		_("Autocorrect colors")
+#define RADIO_BUTTON_OCR_USE_GUI_PIPE			_("Use GUI progress pipe")
+#define RADIO_BUTTON_EMBED_ICM_PROFILE			_("Embed scanner/source ICM profile into image file")
 
-#define BUTTON_SCAN			_("Scan")
-#define BUTTON_OK			_("Ok")
-#define BUTTON_ACCEPT			_("Accept")
-#define BUTTON_NOT_ACCEPT		_("Not accept")
-#define BUTTON_APPLY			_("Apply")
-#define BUTTON_CANCEL			_("Cancel")
-#define BUTTON_REDUCE			_("Reduce")
-#define BUTTON_CONT_AT_OWN_RISK		_("Continue at your own risk")
-#define BUTTON_BROWSE			_("Browse")
-#define BUTTON_CLOSE			_("Close")
-#define BUTTON_HELP			_("Help")
-#define BUTTON_OVERWRITE		_("Overwrite")
-#define BUTTON_BATCH_LIST_SCAN		_("Scan batch list")
-#define BUTTON_BATCH_AREA_SCAN		_("Scan selected area")
-#define BUTTON_PAGE_DELETE		_("Delete page")
-#define BUTTON_PAGE_SHOW		_("Show page")
-#define BUTTON_PAGE_RENAME		_("Rename page")
-#define BUTTON_IMAGE_DELETE		_("Delete image")
-#define BUTTON_IMAGE_SHOW		_("Show image")
-#define BUTTON_IMAGE_EDIT		_("Edit image")
-#define BUTTON_IMAGE_RENAME		_("Rename image")
-#define BUTTON_FILE_INSERT		_("Insert file")
-#define BUTTON_CREATE_PROJECT		_("Create project")
-#define BUTTON_SEND_PROJECT		_("Send project")
-#define BUTTON_SAVE_MULTIPAGE		_("Save multipage file")
-#define BUTTON_DELETE_PROJECT		_("Delete project")
-#define BUTTON_ADD_PRINTER		_("Add printer")
-#define BUTTON_DELETE_PRINTER		_("Delete printer")
-#define BUTTON_PREVIEW_ACQUIRE		_("Acquire preview")
-#define BUTTON_PREVIEW_CANCEL		_("Cancel preview")
-#define BUTTON_DISCARD_IMAGE		_("Discard image")
-#define BUTTON_DISCARD_ALL_IMAGES	_("Discard all images")
-#define BUTTON_DO_NOT_CLOSE		_("Do not close")
-#define BUTTON_SCALE_BIND		_("Bind scale")
-
-#define RADIO_BUTTON_FINE_MODE		_("Fine mode")
-#define RADIO_BUTTON_HTML_EMAIL		_("HTML e-mail")
-#define RADIO_BUTTON_SAVE_DEVPREFS_AT_EXIT _("Save device preferences at exit")
-#define RADIO_BUTTON_OVERWRITE_WARNING	_("Overwrite warning")
-#define RADIO_BUTTON_SKIP_EXISTING_NRS	_("Skip existing filenames")
-#define RADIO_BUTTON_SAVE_PS_FLATDECODED _("Save postscript zlib compressed (ps level 3)")
-#define RADIO_BUTTON_SAVE_PDF_FLATDECODED _("Save PDF zlib compressed")
-#define RADIO_BUTTON_SAVE_PNM16_AS_ASCII _("Save 16bit pnm in ascii format")
-#define RADIO_BUTTON_REDUCE_16BIT_TO_8BIT _("Reduce 16 bit image to 8 bit")
-#define RADIO_BUTTON_WINDOW_FIXED	_("Main window size fixed")
-#define RADIO_BUTTON_DISABLE_GIMP_PREVIEW_GAMMA	_("Disable gimp preview gamma")
-#define RADIO_BUTTON_PRIVATE_COLORMAP	_("Use private colormap")
-#define RADIO_BUTTON_AUTOENHANCE_GAMMA  _("Autoenhance gamma")
-#define RADIO_BUTTON_PRESELECT_SCANAREA _("Preselect scanarea")
-#define RADIO_BUTTON_AUTOCORRECT_COLORS _("Autocorrect colors")
-#define RADIO_BUTTON_OCR_USE_GUI_PIPE	_("Use GUI progress pipe")
-
-#define TEXT_SCANNING_DEVICES		_("scanning for devices")
-#define TEXT_AVAILABLE_DEVICES		_("Available devices:")
-#define TEXT_XSANE_OPTIONS		_("XSane options")
-#define TEXT_FILETYPE			_("Type")
-#define TEXT_SCANNER_BACKEND		_("Scanner and backend:")
-#define TEXT_VENDOR			_("Vendor:")
-#define TEXT_MODEL			_("Model:")
-#define TEXT_TYPE			_("Type:")
-#define TEXT_DEVICE			_("Device:")
-#define TEXT_LOADED_BACKEND		_("Loaded backend:")
-#define TEXT_SANE_VERSION		_("Sane version:")
-#define TEXT_RECENT_VALUES		_("Recent values:")
-#define TEXT_GAMMA_CORR_BY		_("Gamma correction by:")
-#define TEXT_SCANNER			_("scanner")
-#define TEXT_SOFTWARE_XSANE		_("software (XSane)")
-#define TEXT_NONE			_("none")
-#define TEXT_GAMMA_INPUT_DEPTH		_("Gamma input depth:")
-#define TEXT_GAMMA_OUTPUT_DEPTH		_("Gamma output depth:")
-#define TEXT_SCANNER_OUTPUT_DEPTH	_("Scanner output depth:")
-#define TEXT_OUTPUT_FORMATS		_("XSane output formats:")
-#define TEXT_8BIT_FORMATS		_("8 bit output formats:")
-#define TEXT_16BIT_FORMATS		_("16 bit output formats:")
-#define TEXT_GIMP_REDUCE_16BIT_TO_8BIT	_("Gimp does not support depth 16 bits/color.\n" \
-                                          "Do you want to reduce the depth to 8 bits/color?")
-#define TEXT_REDUCE_16BIT_TO_8BIT	_("Bit depth 16 bits/color is not supported for this output format.\n" \
-                                          "Do you want to reduce the depth to 8 bits/color?")
-#define TEXT_AUTHORIZATION_REQ		_("Authorization required for")
-#define TEXT_AUTHORIZATION_SECURE	_("Password transmission is secure")
-#define TEXT_AUTHORIZATION_INSECURE	_("Backend requests plain-text password")
-#define TEXT_USERNAME			_("Username :")
-#define TEXT_PASSWORD			_("Password :")
-#define TEXT_INVALID_PARAMS		_("Invalid parameters.")
-#define TEXT_VERSION			_("version:")
-#define TEXT_PACKAGE			_("package")
-#define TEXT_WITH_GIMP_SUPPORT		_("with GIMP support")
-#define TEXT_WITHOUT_GIMP_SUPPORT	_("without GIMP support")
-#define TEXT_GTK_VERSION		_("compiled with GTK-")
-#define TEXT_GIMP_VERSION		_("compiled with GIMP-")
-#define TEXT_UNKNOWN			_("unknown")
+#define TEXT_SCANNING_DEVICES				_("scanning for devices")
+#define TEXT_AVAILABLE_DEVICES				_("Available devices:")
+#define TEXT_XSANE_OPTIONS				_("XSane options")
+#define TEXT_FILETYPE					_("Type")
+#define TEXT_SCANNER_BACKEND				_("Scanner and backend:")
+#define TEXT_VENDOR					_("Vendor:")
+#define TEXT_MODEL					_("Model:")
+#define TEXT_TYPE					_("Type:")
+#define TEXT_DEVICE					_("Device:")
+#define TEXT_LOADED_BACKEND				_("Loaded backend:")
+#define TEXT_SANE_VERSION				_("Sane version:")
+#define TEXT_RECENT_VALUES				_("Recent values:")
+#define TEXT_GAMMA_CORR_BY				_("Gamma correction by:")
+#define TEXT_SCANNER					_("scanner")
+#define TEXT_SOFTWARE_XSANE				_("software (XSane)")
+#define TEXT_NONE					_("none")
+#define TEXT_GAMMA_INPUT_DEPTH				_("Gamma input depth:")
+#define TEXT_GAMMA_OUTPUT_DEPTH				_("Gamma output depth:")
+#define TEXT_SCANNER_OUTPUT_DEPTH			_("Scanner output depth:")
+#define TEXT_OUTPUT_FORMATS				_("XSane output formats:")
+#define TEXT_8BIT_FORMATS				_("8 bit output formats:")
+#define TEXT_16BIT_FORMATS				_("16 bit output formats:")
+#define TEXT_GIMP_REDUCE_16BIT_TO_8BIT			_("Gimp does not support depth 16 bits/color.\n" \
+                                        		  "Do you want to reduce the depth to 8 bits/color?")
+#define TEXT_REDUCE_16BIT_TO_8BIT			_("Bit depth 16 bits/color is not supported for this output format.\n" \
+                                        		  "Do you want to reduce the depth to 8 bits/color?")
+#define TEXT_AUTHORIZATION_REQ				_("Authorization required for")
+#define TEXT_AUTHORIZATION_SECURE			_("Password transmission is secure")
+#define TEXT_AUTHORIZATION_INSECURE			_("Backend requests plain-text password")
+#define TEXT_USERNAME					_("Username :")
+#define TEXT_PASSWORD					_("Password :")
+#define TEXT_INVALID_PARAMS				_("Invalid parameters.")
+#define TEXT_VERSION					_("version:")
+#define TEXT_PACKAGE					_("package")
+#define TEXT_WITH_CMS_FUNCTION				_("with color management function")
+#define TEXT_WITH_GIMP_SUPPORT				_("with GIMP support")
+#define TEXT_WITHOUT_GIMP_SUPPORT			_("without GIMP support")
+#define TEXT_GTK_VERSION				_("compiled with GTK-")
+#define TEXT_GIMP_VERSION				_("compiled with GIMP-")
+#define TEXT_UNKNOWN					_("unknown")
 #define TEXT_EULA			_( "XSane is distributed under the terms of the GNU General Public License\n" \
                                           "as published by the Free Software Foundation; either version 2 of the\n" \
                                           "License, or (at your option) any later version.\n" \
@@ -220,164 +228,193 @@
                                           "This program is distributed in the hope that it will be useful, but\n" \
                                           "WITHOUT ANY WARRANTY; without even the implied warranty of\n" \
                                           "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.\n")
-#define TEXT_EMAIL_ADR			_("E-mail:")
-#define TEXT_HOMEPAGE			_("Homepage:")
-#define TEXT_FILE			_("File:")
-#define TEXT_TRANSLATION		_("Translation:")
+#define TEXT_EMAIL_ADR					_("E-mail:")
+#define TEXT_HOMEPAGE					_("Homepage:")
+#define TEXT_FILE					_("File:")
+#define TEXT_TRANSLATION				_("Translation:")
 
 /* Please translate this to something like */
 /* translation to YOUR LANGUAGE\n */
 /* by YOUR NAME\n */
 /* E-mail: your.name@yourdomain.com\n */
-#define TEXT_TRANSLATION_INFO		_("untranslated original english text\n" \
-					  "by Oliver Rauch\n" \
-					  "E-mail: Oliver.Rauch@rauch-domain.de\n")
+#define TEXT_TRANSLATION_INFO				_("untranslated original english text\n" \
+							  "by Oliver Rauch\n" \
+							  "E-mail: Oliver.Rauch@rauch-domain.de\n")
 
-#define TEXT_INFO_BOX			_("0x0: 0KB")
+#define TEXT_INFO_BOX					_("0x0: 0KB")
 
-#define TEXT_ADF_PAGES_SCANNED		_("Scanned pages: ")
+#define TEXT_ADF_PAGES_SCANNED				_("Scanned pages: ")
 
-#define TEXT_EMAIL_TEXT			_("E-mail text:")
-#define TEXT_ATTACHMENTS		_("Attachments:")
-#define TEXT_EMAIL_STATUS		_("Project status:")
-#define TEXT_EMAIL_FILETYPE		_("E-mail image filetype:")
+#define TEXT_EMAIL_TEXT					_("E-mail text:")
+#define TEXT_ATTACHMENTS				_("Attachments:")
+#define TEXT_EMAIL_STATUS				_("Project status:")
+#define TEXT_EMAIL_FILETYPE				_("E-mail image filetype:")
 
-#define TEXT_PAGES			_("Pages:")
-#define TEXT_MULTIPAGE_FILETYPE		_("Multipage document filetype:")
+#define TEXT_PAGES					_("Pages:")
+#define TEXT_MULTIPAGE_FILETYPE				_("Multipage document filetype:")
 
-#define TEXT_MEDIUM_DEFINITION_NAME	_("Medium Name:")
+#define TEXT_MEDIUM_DEFINITION_NAME			_("Medium Name:")
 
-#define TEXT_VIEWER_IMAGE_INFO		_("Size %d x %d pixel, %d bit/color, %d colors, %1.0f dpi x %1.0f dpi, %1.1f %s")
-#define TEXT_DESPECKLE_RADIUS		_("Despeckle radius:")
-#define TEXT_BLUR_RADIUS		_("Blur radius:")
-#define TEXT_BATCH_AREA_DEFAULT_NAME	_("(no name)")
-#define TEXT_BATCH_LIST_AREANAME	_("Area name:")
-#define TEXT_BATCH_LIST_SCANMODE	_("Scanmode:")
-#define TEXT_BATCH_LIST_GEOMETRY_TL	_("Top left:")
-#define TEXT_BATCH_LIST_GEOMETRY_SIZE	_("Size:")
-#define TEXT_BATCH_LIST_RESOLUTION	_("Resolution:")
-#define TEXT_BATCH_LIST_BIT_DEPTH	_("Bit depth:")
-#define TEXT_BATCH_LIST_BY_GUI		_("as selected")
+#define TEXT_VIEWER_IMAGE_INFO				_("Size %d x %d pixel, %d bit/color, %d colors, %1.0f dpi x %1.0f dpi, %1.1f %s")
+#define TEXT_DESPECKLE_RADIUS				_("Despeckle radius:")
+#define TEXT_BLUR_RADIUS				_("Blur radius:")
+#define TEXT_BATCH_AREA_DEFAULT_NAME			_("(no name)")
+#define TEXT_BATCH_LIST_AREANAME			_("Area name:")
+#define TEXT_BATCH_LIST_SCANMODE			_("Scanmode:")
+#define TEXT_BATCH_LIST_GEOMETRY_TL			_("Top left:")
+#define TEXT_BATCH_LIST_GEOMETRY_SIZE			_("Size:")
+#define TEXT_BATCH_LIST_RESOLUTION			_("Resolution:")
+#define TEXT_BATCH_LIST_BIT_DEPTH			_("Bit depth:")
+#define TEXT_BATCH_LIST_BY_GUI				_("as selected")
 
-#define TEXT_SETUP_PRINTER_SEL		_("Printer selection:")
-#define TEXT_SETUP_PRINTER_NAME		_("Name:")
-#define TEXT_SETUP_PRINTER_CMD		_("Command:")
-#define TEXT_SETUP_COPY_NR_OPT		_("Copy number option:")
-#define TEXT_SETUP_PRINTER_LINEART_RES	_("Lineart resolution (dpi):")
-#define TEXT_SETUP_PRINTER_GRAYSCALE_RES _("Grayscale resolution (dpi):")
-#define TEXT_SETUP_PRINTER_COLOR_RES	_("Color resolution (dpi):")
-#define TEXT_SETUP_PRINTER_WIDTH	_("Width")
-#define TEXT_SETUP_PRINTER_HEIGHT	_("Height")
-#define TEXT_SETUP_PRINTER_LEFT		_("Left offset")
-#define TEXT_SETUP_PRINTER_BOTTOM	_("Bottom offset")
-#define TEXT_SETUP_PRINTER_GAMMA	_("Printer gamma value:")
-#define TEXT_SETUP_PRINTER_GAMMA_RED	_("Printer gamma red:")
-#define TEXT_SETUP_PRINTER_GAMMA_GREEN	_("Printer gamma green:")
-#define TEXT_SETUP_PRINTER_GAMMA_BLUE	_("Printer gamma blue:")
-#define TEXT_SETUP_PRINTER_PS_FLATDECODED _("Create zlib compressed postscript image (ps level 3) for printing")
-#define TEXT_SETUP_TMP_PATH		_("Temporary directory")
-#define TEXT_SETUP_IMAGE_PERMISSION	_("Image-file permissions")
-#define TEXT_SETUP_DIR_PERMISSION	_("Directory permissions")
-#define TEXT_SETUP_JPEG_QUALITY		_("JPEG image quality")
-#define TEXT_SETUP_PNG_COMPRESSION	_("PNG image compression")
-#define TEXT_SETUP_FILENAME_COUNTER_LEN	_("Filename counter length")
-#define TEXT_SETUP_TIFF_ZIP_COMPRESSION	_("TIFF zip compression rate")
-#define TEXT_SETUP_TIFF_COMPRESSION_16	_("TIFF 16 bit image compression")
-#define TEXT_SETUP_TIFF_COMPRESSION_8	_("TIFF 8 bit image compression")
-#define TEXT_SETUP_TIFF_COMPRESSION_1	_("TIFF lineart image compression")
-#define TEXT_SETUP_SHOW_RANGE_MODE	_("Show range as:")
-#define TEXT_SETUP_PREVIEW_OVERSAMPLING	_("Preview oversampling:")
-#define TEXT_SETUP_PREVIEW_GAMMA	_("Preview gamma:")
-#define TEXT_SETUP_PREVIEW_GAMMA_RED	_("Preview gamma red:")
-#define TEXT_SETUP_PREVIEW_GAMMA_GREEN	_("Preview gamma green:")
-#define TEXT_SETUP_PREVIEW_GAMMA_BLUE	_("Preview gamma blue:")
-#define TEXT_SETUP_LINEART_MODE         _("Threshold option:")
-#define TEXT_SETUP_PREVIEW_PIPETTE_RANGE _("Preview pipette range")
-#define TEXT_SETUP_THRESHOLD_MIN        _("Threshold minimum:")
-#define TEXT_SETUP_THRESHOLD_MAX        _("Threshold maximum:")
-#define TEXT_SETUP_THRESHOLD_MUL        _("Threshold multiplier:")
-#define TEXT_SETUP_THRESHOLD_OFF        _("Threshold offset:")
-#define TEXT_SETUP_GRAYSCALE_SCANMODE   _("Name of grayscale scanmode:")
-#define TEXT_SETUP_HELPFILE_VIEWER	_("Helpfile viewer (HTML):")
-#define TEXT_SETUP_FAX_COMMAND		_("Command:")
-#define TEXT_SETUP_FAX_RECEIVER_OPTION	_("Receiver option:")
-#define TEXT_SETUP_FAX_POSTSCRIPT_OPT	_("Postscriptfile option:")
-#define TEXT_SETUP_FAX_NORMAL_MODE_OPT	_("Normal mode option:")
-#define TEXT_SETUP_FAX_FINE_MODE_OPT	_("Fine mode option:")
-#define TEXT_SETUP_FAX_PROGRAM_DEFAULTS _("Set program defaults for:")
-#define TEXT_SETUP_FAX_VIEWER		_("Viewer (Postscript):")
-#define TEXT_SETUP_FAX_WIDTH		_("Width")
-#define TEXT_SETUP_FAX_HEIGHT		_("Height")
-#define TEXT_SETUP_FAX_LEFT		_("Left offset")
-#define TEXT_SETUP_FAX_BOTTOM		_("Bottom offset")
-#define TEXT_SETUP_FAX_PS_FLATDECODED	_("Create zlib compressed postscript image (ps level 3) for fax")
-#define TEXT_SETUP_SMTP_SERVER		_("SMTP server:")
-#define TEXT_SETUP_SMTP_PORT		_("SMTP port:")
-#define TEXT_SETUP_EMAIL_FROM		_("From:")
-#define TEXT_SETUP_EMAIL_REPLY_TO	_("Reply to:")
-#define TEXT_SETUP_EMAIL_AUTHENTICATION	_("E-mail authentication")
-#define TEXT_SETUP_EMAIL_AUTH_USER	_("User:")
-#define TEXT_SETUP_EMAIL_AUTH_PASS	_("Password:")
-#define TEXT_SETUP_POP3_SERVER		_("POP3 server:")
-#define TEXT_SETUP_POP3_PORT		_("POP3 port:")
-#define TEXT_SETUP_OCR_COMMAND		_("OCR Command:")
-#define TEXT_SETUP_OCR_INPUTFILE_OPT	_("Inputfile option:")
-#define TEXT_SETUP_OCR_OUTPUTFILE_OPT	_("Outputfile option:")
-#define TEXT_SETUP_OCR_USE_GUI_PIPE_OPT	_("Use GUI progress pipe:")
-#define TEXT_SETUP_OCR_OUTFD_OPT	_("GUI output-fd option:")
-#define TEXT_SETUP_OCR_PROGRESS_KEYWORD	_("Progress keyword:")
-#define TEXT_SETUP_PERMISSION_USER	_("user")
-#define TEXT_SETUP_PERMISSION_GROUP	_("group")
-#define TEXT_SETUP_PERMISSION_ALL	_("all")
-#define	TEXT_NEW_MEDIA_NAME		_("new media")
+#define TEXT_SETUP_PRINTER_SEL				_("Printer selection:")
+#define TEXT_SETUP_PRINTER_NAME				_("Name:")
+#define TEXT_SETUP_PRINTER_CMD				_("Command:")
+#define TEXT_SETUP_COPY_NR_OPT				_("Copy number option:")
+#define TEXT_SETUP_PRINTER_LINEART_RES			_("Lineart resolution (dpi):")
+#define TEXT_SETUP_PRINTER_GRAYSCALE_RES		_("Grayscale resolution (dpi):")
+#define TEXT_SETUP_PRINTER_COLOR_RES			_("Color resolution (dpi):")
+#define TEXT_SETUP_PRINTER_WIDTH			_("Width")
+#define TEXT_SETUP_PRINTER_HEIGHT			_("Height")
+#define TEXT_SETUP_PRINTER_LEFT				_("Left offset")
+#define TEXT_SETUP_PRINTER_BOTTOM			_("Bottom offset")
+#define TEXT_SETUP_PRINTER_GAMMA			_("Printer gamma value:")
+#define TEXT_SETUP_PRINTER_GAMMA_RED			_("Printer gamma red:")
+#define TEXT_SETUP_PRINTER_GAMMA_GREEN			_("Printer gamma green:")
+#define TEXT_SETUP_PRINTER_GAMMA_BLUE			_("Printer gamma blue:")
+#define TEXT_SETUP_PRINTER_PS_FLATDECODED		_("Create zlib compressed postscript image (ps level 3) for printing")
+#define TEXT_SETUP_TMP_PATH				_("Temporary directory")
+#define TEXT_SETUP_IMAGE_PERMISSION			_("Image-file permissions")
+#define TEXT_SETUP_DIR_PERMISSION			_("Directory permissions")
+#define TEXT_SETUP_JPEG_QUALITY				_("JPEG image quality")
+#define TEXT_SETUP_PNG_COMPRESSION			_("PNG image compression")
+#define TEXT_SETUP_FILENAME_COUNTER_LEN			_("Filename counter length")
+#define TEXT_SETUP_TIFF_ZIP_COMPRESSION			_("TIFF zip compression rate")
+#define TEXT_SETUP_TIFF_COMPRESSION_16			_("TIFF 16 bit image compression")
+#define TEXT_SETUP_TIFF_COMPRESSION_8			_("TIFF 8 bit image compression")
+#define TEXT_SETUP_TIFF_COMPRESSION_1			_("TIFF lineart image compression")
+#define TEXT_SETUP_SHOW_RANGE_MODE			_("Show range as:")
+#define TEXT_SETUP_PREVIEW_OVERSAMPLING			_("Preview oversampling:")
+#define TEXT_SETUP_PREVIEW_GAMMA			_("Preview gamma:")
+#define TEXT_SETUP_PREVIEW_GAMMA_RED			_("Preview gamma red:")
+#define TEXT_SETUP_PREVIEW_GAMMA_GREEN			_("Preview gamma green:")
+#define TEXT_SETUP_PREVIEW_GAMMA_BLUE			_("Preview gamma blue:")
+#define TEXT_SETUP_LINEART_MODE         		_("Threshold option:")
+#define TEXT_SETUP_PREVIEW_PIPETTE_RANGE		 _("Preview pipette range")
+#define TEXT_SETUP_THRESHOLD_MIN        		_("Threshold minimum:")
+#define TEXT_SETUP_THRESHOLD_MAX        		_("Threshold maximum:")
+#define TEXT_SETUP_THRESHOLD_MUL        		_("Threshold multiplier:")
+#define TEXT_SETUP_THRESHOLD_OFF        		_("Threshold offset:")
+#define TEXT_SETUP_GRAYSCALE_SCANMODE			_("Name of grayscale scanmode:")
+#define TEXT_SETUP_HELPFILE_VIEWER			_("Helpfile viewer (HTML):")
+#define TEXT_SETUP_FAX_COMMAND				_("Command:")
+#define TEXT_SETUP_FAX_RECEIVER_OPTION			_("Receiver option:")
+#define TEXT_SETUP_FAX_POSTSCRIPT_OPT			_("Postscriptfile option:")
+#define TEXT_SETUP_FAX_NORMAL_MODE_OPT			_("Normal mode option:")
+#define TEXT_SETUP_FAX_FINE_MODE_OPT			_("Fine mode option:")
+#define TEXT_SETUP_FAX_PROGRAM_DEFAULTS 		_("Set program defaults for:")
+#define TEXT_SETUP_FAX_VIEWER				_("Viewer (Postscript):")
+#define TEXT_SETUP_FAX_WIDTH				_("Width")
+#define TEXT_SETUP_FAX_HEIGHT				_("Height")
+#define TEXT_SETUP_FAX_LEFT				_("Left offset")
+#define TEXT_SETUP_FAX_BOTTOM				_("Bottom offset")
+#define TEXT_SETUP_FAX_PS_FLATDECODED			_("Create zlib compressed postscript image (ps level 3) for fax")
+#define TEXT_SETUP_SMTP_SERVER				_("SMTP server:")
+#define TEXT_SETUP_SMTP_PORT				_("SMTP port:")
+#define TEXT_SETUP_EMAIL_FROM				_("From:")
+#define TEXT_SETUP_EMAIL_REPLY_TO			_("Reply to:")
+#define TEXT_SETUP_EMAIL_AUTHENTICATION			_("E-mail authentication")
+#define TEXT_SETUP_EMAIL_AUTH_USER			_("User:")
+#define TEXT_SETUP_EMAIL_AUTH_PASS			_("Password:")
+#define TEXT_SETUP_POP3_SERVER				_("POP3 server:")
+#define TEXT_SETUP_POP3_PORT				_("POP3 port:")
+#define TEXT_SETUP_OCR_COMMAND				_("OCR Command:")
+#define TEXT_SETUP_OCR_INPUTFILE_OPT			_("Inputfile option:")
+#define TEXT_SETUP_OCR_OUTPUTFILE_OPT			_("Outputfile option:")
+#define TEXT_SETUP_OCR_USE_GUI_PIPE_OPT			_("Use GUI progress pipe:")
+#define TEXT_SETUP_OCR_OUTFD_OPT			_("GUI output-fd option:")
+#define TEXT_SETUP_OCR_PROGRESS_KEYWORD			_("Progress keyword:")
+#define TEXT_SETUP_PERMISSION_USER			_("user")
+#define TEXT_SETUP_PERMISSION_GROUP			_("group")
+#define TEXT_SETUP_PERMISSION_ALL			_("all")
+#define TEXT_SETUP_SCANNER_REFL_ICM_PROFILE		_("Scanner reflective ICM-profile")
+#define TEXT_SETUP_SCANNER_TRAN_ICM_PROFILE		_("Scanner transmissive ICM-profile")
+#define TEXT_SETUP_DISPLAY_ICM_PROFILE			_("Display ICM-profile")
+#define TEXT_SETUP_CUSTOM_PROOFING_ICM_PROFILE		_("Custom proofing ICM-profile")
+#define TEXT_SETUP_PRINTER_ICM_PROFILE			_("Printer ICM-profile")
+#define	TEXT_NEW_MEDIA_NAME				_("new media")
 
-#define NOTEBOOK_SAVING_OPTIONS		_("Save")
-#define NOTEBOOK_FILETYPE_OPTIONS	_("Filetype")
-#define NOTEBOOK_COPY_OPTIONS		_("Copy")
-#define NOTEBOOK_FAX_OPTIONS		_("Fax")
-#define NOTEBOOK_EMAIL_OPTIONS		_("E-mail")
-#define NOTEBOOK_OCR_OPTIONS		_("OCR")
-#define NOTEBOOK_DISPLAY_OPTIONS	_("Display")
-#define NOTEBOOK_ENHANCE_OPTIONS	_("Enhancement")
+#define NOTEBOOK_SAVING_OPTIONS				_("Save")
+#define NOTEBOOK_FILETYPE_OPTIONS			_("Filetype")
+#define NOTEBOOK_COPY_OPTIONS				_("Copy")
+#define NOTEBOOK_FAX_OPTIONS				_("Fax")
+#define NOTEBOOK_EMAIL_OPTIONS				_("E-mail")
+#define NOTEBOOK_OCR_OPTIONS				_("OCR")
+#define NOTEBOOK_DISPLAY_OPTIONS			_("Display")
+#define NOTEBOOK_ENHANCE_OPTIONS			_("Enhancement")
+#define NOTEBOOK_COLOR_MANAGEMENT_OPTIONS		_("Color management")
 
-#define MENU_ITEM_SAVE			_("Save")
-#define MENU_ITEM_VIEWER		_("Viewer")
-#define MENU_ITEM_COPY			_("Copy")
-#define MENU_ITEM_MULTIPAGE		_("Multipage")
-#define MENU_ITEM_FAX			_("Fax")
-#define MENU_ITEM_EMAIL			_("E-mail")
+#define MENU_ITEM_SAVE					_("Save")
+#define MENU_ITEM_VIEWER				_("Viewer")
+#define MENU_ITEM_COPY					_("Copy")
+#define MENU_ITEM_MULTIPAGE				_("Multipage")
+#define MENU_ITEM_FAX					_("Fax")
+#define MENU_ITEM_EMAIL					_("E-mail")
 
-#define MENU_ITEM_SHOW_TOOLTIPS		_("Show tooltips")
-#define MENU_ITEM_SHOW_PREVIEW		_("Show preview")
-#define MENU_ITEM_SHOW_HISTOGRAM	_("Show histogram")
-#define MENU_ITEM_SHOW_GAMMA		_("Show gamma curve")
-#define MENU_ITEM_SHOW_BATCH_SCAN	_("Show batch scan")
-#define MENU_ITEM_SHOW_STANDARDOPTIONS	_("Show standard options")
-#define MENU_ITEM_SHOW_ADVANCEDOPTIONS	_("Show advanced options")
+#define MENU_ITEM_SHOW_TOOLTIPS				_("Show tooltips")
+#define MENU_ITEM_SHOW_PREVIEW				_("Show preview")
+#define MENU_ITEM_SHOW_HISTOGRAM			_("Show histogram")
+#define MENU_ITEM_SHOW_GAMMA				_("Show gamma curve")
+#define MENU_ITEM_SHOW_BATCH_SCAN			_("Show batch scan")
+#define MENU_ITEM_SHOW_STANDARDOPTIONS			_("Show standard options")
+#define MENU_ITEM_SHOW_ADVANCEDOPTIONS			_("Show advanced options")
 
-#define MENU_ITEM_SETUP			_("Setup")
-#define MENU_ITEM_LENGTH_UNIT		_("Length unit")
-#define SUBMENU_ITEM_LENGTH_MILLIMETERS	_("millimeters")
-#define SUBMENU_ITEM_LENGTH_CENTIMETERS	_("centimeters")
-#define SUBMENU_ITEM_LENGTH_INCHES	_("inches")
-#define MENU_ITEM_UPDATE_POLICY		_("Update policy")
-#define SUBMENU_ITEM_POLICY_CONTINUOUS	_("continuous")
-#define SUBMENU_ITEM_POLICY_DISCONTINU	_("discontinuous")
-#define SUBMENU_ITEM_POLICY_DELAYED	_("delayed")
-#define MENU_ITEM_SHOW_RESOLUTIONLIST	_("Show resolution list")
-#define MENU_ITEM_PAGE_ROTATE		_("Rotate postscript")
-#define MENU_ITEM_EDIT_MEDIUM_DEF	_("Edit medium definition")
-#define MENU_ITEM_SAVE_DEVICE_SETTINGS	_("Save device settings")
-#define MENU_ITEM_LOAD_DEVICE_SETTINGS	_("Load device settings")
-#define MENU_ITEM_CHANGE_WORKING_DIR	_("Change directory")
+#define MENU_ITEM_SETUP					_("Setup")
+#define MENU_ITEM_LENGTH_UNIT				_("Length unit")
+#define SUBMENU_ITEM_LENGTH_MILLIMETERS			_("millimeters")
+#define SUBMENU_ITEM_LENGTH_CENTIMETERS			_("centimeters")
+#define SUBMENU_ITEM_LENGTH_INCHES			_("inches")
+#define MENU_ITEM_UPDATE_POLICY				_("Update policy")
+#define SUBMENU_ITEM_POLICY_CONTINUOUS			_("continuous")
+#define SUBMENU_ITEM_POLICY_DISCONTINU			_("discontinuous")
+#define SUBMENU_ITEM_POLICY_DELAYED			_("delayed")
+#define MENU_ITEM_SHOW_RESOLUTIONLIST			_("Show resolution list")
+#define MENU_ITEM_PAGE_ROTATE				_("Rotate postscript")
+#define MENU_ITEM_ENABLE_COLOR_MANAGEMENT		_("Enable color management")
+#define MENU_ITEM_EDIT_MEDIUM_DEF			_("Edit medium definition")
+#define MENU_ITEM_SAVE_DEVICE_SETTINGS			_("Save device settings")
+#define MENU_ITEM_LOAD_DEVICE_SETTINGS			_("Load device settings")
+#define MENU_ITEM_CHANGE_WORKING_DIR			_("Change directory")
 
-#define MENU_ITEM_XSANE_EULA		_("Show EULA")
-#define MENU_ITEM_XSANE_GPL		_("Show license (GPL)")
-#define MENU_ITEM_XSANE_DOC		_("XSane doc")
-#define MENU_ITEM_BACKEND_DOC		_("Backend doc")
-#define MENU_ITEM_AVAILABLE_BACKENDS	_("Available backends")
-#define MENU_ITEM_SCANTIPS		_("Scantips")
-#define MENU_ITEM_PROBLEMS		_("Problems?")
+#define MENU_ITEM_XSANE_EULA				_("Show EULA")
+#define MENU_ITEM_XSANE_GPL				_("Show license (GPL)")
+#define MENU_ITEM_XSANE_DOC				_("XSane doc")
+#define MENU_ITEM_BACKEND_DOC				_("Backend doc")
+#define MENU_ITEM_AVAILABLE_BACKENDS			_("Available backends")
+#define MENU_ITEM_SCANTIPS				_("Scantips")
+#define MENU_ITEM_PROBLEMS				_("Problems?")
+
+
+#define MENU_ITEM_CMS_ENABLE_COLOR_MANAGEMENT		_("Enable color management")
+#define MENU_ITEM_CMS_BLACK_POINT_COMPENSATION		_("Black point compensation")
+#define MENU_ITEM_CMS_PROOFING				_("Proofing")
+#define SUBMENU_ITEM_CMS_PROOF_OFF			_("no proofing (Display)")
+#define SUBMENU_ITEM_CMS_PROOF_PRINTER			_("Proof printer")
+#define SUBMENU_ITEM_CMS_PROOF_CUSTOM			_("Proof custom device")
+#define MENU_ITEM_CMS_RENDERING_INTENT			_("Rendering intent")
+#define MENU_ITEM_CMS_PROOFING_INTENT			_("Proofing rendering intent")
+#define SUBMENU_ITEM_CMS_INTENT_PERCEPTUAL		_("Perceptual")
+#define SUBMENU_ITEM_CMS_INTENT_RELATIVE_COLORIMETRIC	_("Relative colorimetric")
+#define SUBMENU_ITEM_CMS_INTENT_ABSOLUTE_COLORIMETRIC	_("Absolute colorimentric")
+#define SUBMENU_ITEM_CMS_INTENT_SATURATION		_("Saturation")
+#define MENU_ITEM_CMS_GAMUT_CHECK			_("Gamut check")
+#define MENU_ITEM_CMS_GAMUT_ALARM_COLOR			_("Gamut alarm color")
+#define SUBMENU_ITEM_CMS_COLOR_BLACK			_("Black")
+#define SUBMENU_ITEM_CMS_COLOR_GRAY			_("Gray")
+#define SUBMENU_ITEM_CMS_COLOR_WHITE			_("White")
+#define SUBMENU_ITEM_CMS_COLOR_RED			_("Red")
+#define SUBMENU_ITEM_CMS_COLOR_GREEN			_("Green")
+#define SUBMENU_ITEM_CMS_COLOR_BLUE			_("Blue")
 
 #define MENU_ITEM_COUNTER_LEN_INACTIVE	_("inactive")
 #define MENU_ITEM_TIFF_COMP_NONE	_("no compression")
@@ -495,7 +532,7 @@
 						" brightness = 0\n" \
 						" contrast = 0")
 
-#define DESC_ENH_AUTO			_("Autoadjust gamma, brightness and contrast <Ctrl-e>")
+#define DESC_ENH_AUTO			_("Autoadjust gamma, brightness and contrast <Ctrl-a>")
 #define DESC_ENH_DEFAULT		_("Set default enhancement values <Ctrl-0>:\n" \
 						"gamma = 1.0\n" \
 						"brightness = 0\n" \
@@ -575,6 +612,8 @@
 #define DESC_PRESELECT_SCANAREA		_("Select scanarea after preview scan has finished")
 #define DESC_AUTOCORRECT_COLORS		_("Do color correction after preview scan has finished")
 
+#define DESC_EMBED_ICM_PROFILE		_("Embed scanner/source ICM profile into image file - when fileformat supports it")
+
 #define DESC_FAX_COMMAND		_("Enter command to be executed in fax mode")
 #define DESC_FAX_RECEIVER_OPT		_("Enter option to specify receiver")
 #define DESC_FAX_POSTSCRIPT_OPT		_("Enter option to specify postscript files following")
@@ -606,7 +645,7 @@
 
 #define DESC_PERMISSION_READ		_("read")
 #define DESC_PERMISSION_WRITE		_("write")
-#define DESC_PERMISSION_EXECUTE		_("execute")
+#define DESC_PERMISSION_SEARCH		_("search")
 
 #define DESC_ADD_BATCH			_("Add selection for batch scan")
 #define DESC_PIPETTE_WHITE		_("Pick white point")
@@ -658,6 +697,17 @@
 #define DESC_BATCH_DEL			_("Delete selected area from batch list")
 #define DESC_AUTOMATIC			_("Turns on automatic mode")
 
+#define DESC_SCANNER_REFL_ICM_PROFILE			_("Scanner reflektive ICM-profile")
+#define DESC_BUTTON_SCANNER_REFL_ICM_PROFILE_BROWSE	_("Browse for scanner reflektive ICM-profile")
+#define DESC_SCANNER_TRAN_ICM_PROFILE			_("Scanner transmissive ICM-profile")
+#define DESC_BUTTON_SCANNER_TRAN_ICM_PROFILE_BROWSE	_("Browse for scanner transmissive ICM-profile")
+#define DESC_DISPLAY_ICM_PROFILE			_("Display ICM-profile")
+#define DESC_BUTTON_DISPLAY_ICM_PROFILE_BROWSE		_("Browse for display ICM-profile")
+#define DESC_PRINTER_ICM_PROFILE			_("Printer ICM-profile")
+#define DESC_BUTTON_PRINTER_ICM_PROFILE_BROWSE		_("Browse for printer ICM-profile")
+#define DESC_CUSTOM_PROOFING_ICM_PROFILE		_("Custom proofing ICM-profile")
+#define DESC_BUTTON_CUSTOM_PROOFING_ICM_PROFILE_BROWSE	_("Browse for custom proofing ICM-profile")
+
 #define ERR_HOME_DIR			_("Failed to determine home directory:")
 #define ERR_CHANGE_WORKING_DIR		_("Failed to change working directory to")
 #define ERR_FILENAME_TOO_LONG		_("Filename too long")
@@ -741,6 +791,14 @@ YOU ARE ALONE!\
 #define ERR_FILE_NOT_POSTSCRIPT		_("File %s is not a postscript file")
 #define ERR_UNSUPPORTED_OUTPUT_FORMAT	_("Unsupported %d-bit output format: %s")
 
+#define ERR_CMS_CONVERSION		_("Error during CMS conversion:")
+#define ERR_CMS_OPEN_ICM_FILE		_("Could not open")
+#define CMS_SCANNER_TRAN_ICM		_("scanner transmissive ICM profile")
+#define CMS_SCANNER_REFL_ICM		_("scanner reflective ICM profile")
+#define CMS_DISPLAY_ICM			_("display ICM profile")
+#define CMS_PROOF_ICM			_("proofing ICM profile")
+#define ERR_CMS_CREATE_TRANSFORM	_("Could not create transform")
+
 #define WARN_VIEWER_IMAGE_NOT_SAVED	_("viewer image is not saved")
 
 #define TEXT_USAGE			_("Usage:")
